/*
 * Copyright (C) Azureus Software, Inc, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details ( see the LICENSE file ).
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.biglybt.ui.swt.views.table.impl;

import com.biglybt.ui.swt.views.table.TableViewSWT;
import com.biglybt.ui.swt.views.table.painted.TableViewPainted;

import com.biglybt.ui.common.table.TableColumnCore;

public class TableViewFactory
{
	public static <V> TableViewSWT<V> createTableViewSWT(
			Class<?> pluginDataSourceType, String _sTableID,
			String _sTextPrefixID, TableColumnCore[] _basicItems,
			String _sDefaultSortOn, int _iTableStyle) {
		return (TableViewSWT<V>) new TableViewPainted(pluginDataSourceType,
				_sTableID, _sTextPrefixID, _basicItems, _sDefaultSortOn,
				_iTableStyle);
	}
}
