/*
 * File    : SuperSeedPeer.java
 * Created : 14 d�c. 2003}
 * By      : Olivier
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details ( see the LICENSE file ).
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.biglybt.core.peer.impl.control;

import com.biglybt.core.peer.impl.PEPeerTransport;

/**
 * @author Olivier
 *
 */
public class SuperSeedPeer implements Comparable{

  public final PEPeerTransport peer;

  public SuperSeedPeer(PEPeerTransport peer) {
    this.peer = peer;
  }

  @Override
  public int compareTo(Object obj) {
    SuperSeedPeer otherPeer = (SuperSeedPeer) obj;
    return this.peer.getUploadHint() - otherPeer.peer.getUploadHint();
  }
}
