/*
 * Copyright (C) Azureus Software, Inc, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details ( see the LICENSE file ).
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.biglybt.ui.swt.progress;

/**
 * A simple listener that can be registered with the ProgressReportingManager to receive notification
 * when any ProgressReporter has a status change
 * @author knguyen
 *
 */
public interface IProgressReportingListener
	extends IProgressReportConstants
{


	/**
	 * Notify that some event has happened
	 * @param eventType
	 * @param reporter The <code>ProgressReporter</code> that reported the change;
	 * @return
	 */
	public int reporting(int eventType, IProgressReporter reporter);
}